@@ -682,6 +682,9 @@ dicto_position_update(DICTO(np->owner), FALSE);
 np->active=FALSE;
 p->rms=0.0;
 p->state=DICTO_STATE_STOPPED;
+#if !defined(GST_CHECK_VERSION)
+gst_element_set_locked_state(np->src, FALSE);
+#endif
 }
 
 static gboolean
@@ -1653,11 +1656,23 @@ switch (p->state) {
 	case DICTO_STATE_RECORDING:
 		g_return_val_if_fail(p->record.pipeline, FALSE);
 		g_debug("dicto: Sending EOS");
-		dicto_position_update(d, FALSE);
+#if defined(GST_CHECK_VERSION)
 		if (!gst_element_send_event(p->record.pipeline, gst_event_new_eos())) {
 			g_warning("Failed to send EOS, forcing stop");
 			dicto_pipeline_stop(p, &p->record);
+			g_signal_emit(G_OBJECT(d), signals[SIGNAL_STOPPED_RECORD], 0, NULL);
 		}
+#else
+		gst_element_set_state(p->record.src, GST_STATE_NULL);
+		if (gst_element_get_state (p->record.src, NULL, NULL, -1)==GST_STATE_CHANGE_SUCCESS) {
+			gst_element_set_locked_state(p->record.src, TRUE);
+		} else {
+			g_warning("Failed to stop src for EOS, forcing stop");			
+			dicto_pipeline_stop(p, &p->record);
+			g_signal_emit(G_OBJECT(d), signals[SIGNAL_STOPPED_RECORD], 0, NULL);
+		}
+#endif
+		dicto_position_update(d, FALSE);
 		return TRUE;
 	break;
 	case DICTO_STATE_PAUSED:
